@@ -24,6 +24,8 @@ ZATHURA_PLUGIN_REGISTER_WITH_FUNCTIONS(
   ZATHURA_PLUGIN_MIMETYPES({
     "application/pdf",
     "application/oxps",
-    "application/epub+zip"
+    "application/epub+zip",
+    "application/x-fictionbook",
+    "text/xml"
   })
 )
